#[repr(u8)]pub enum Syscall {
Show 15 variants
Input = 1,
Output = 2,
PoseidonGL = 3,
Affine256 = 4,
EcAdd = 5,
EcDouble = 6,
KeccakF = 7,
Mod256 = 8,
Halt = 9,
Poseidon2GL = 10,
NativeHash = 11,
CommitPublic = 12,
InvertGL = 13,
SplitGLVec = 14,
MergeGL = 15,
}Expand description
We use repr(u8) to make sure the enum discriminant will fit into the
12 bits of the immediate field of the addi instruction,
Variants
Input = 1
Output = 2
PoseidonGL = 3
Affine256 = 4
EcAdd = 5
EcDouble = 6
KeccakF = 7
Mod256 = 8
Halt = 9
Poseidon2GL = 10
NativeHash = 11
CommitPublic = 12
InvertGL = 13
SplitGLVec = 14
MergeGL = 15
Implementations